import os
import tomllib
from typing import Self

import discord
from pydantic import BaseModel


class Post(BaseModel):
    channel: int
    users: list[int]

    def get_channel(
        self,
        client: discord.Client,
    ) -> discord.Thread | discord.TextChannel:
        """
        Zielkanal für Posts finden
        """

        channel = client.get_channel(self.channel)
        assert isinstance(channel, discord.Thread | discord.TextChannel)

        return channel


class Config(BaseModel):
    discord_token: str
    post: Post

    @classmethod
    def get(cls) -> Self:
        cfg_path = os.getenv(
            key="CONFIG_PATH",
            default="/usr/local/etc/lenaverse-bot/lenaverse-bot.toml",
        )

        with open(cfg_path, "rb") as cfg_file:
            return cls.model_validate(tomllib.load(cfg_file))


CONFIG = Config.get()
